@@ -6,39 +6,39 @@ from dotdict import DotDict
 from webcore import constant
 from webcore import exception
 
-def post(host, url, headers={}, data=None, json=None):
+def post(url, headers={}, data=None, json=None):
     _set_auth_header(headers)
     response = requests.post(
-        host + url, 
+        url, 
         headers=headers, 
         json=json,
         data=data,
         verify=False)
     return _get_response_data(response)
 
-def get(host, url, headers={}, params=None):
+def get(url, headers={}, params=None):
     _set_auth_header(headers)
     response = requests.get(
-        host + url, 
+        url, 
         headers=headers, 
         params=params,
         verify=False)
 
     return _get_response_data(response)
 
-def put(host, url, headers={}, data=None):
+def put(url, headers={}, data=None):
     _set_auth_header(headers)
     response = requests.put(
-        host + url, 
+        url, 
         headers=headers,
         data=data,
         verify=False)
     return _get_response_data(response)
 
-def delete(host, url, headers={}, params=None):
+def delete(url, headers={}, params=None):
     _set_auth_header(headers)
     response = requests.delete(
-        host + url, 
+        url, 
         headers=headers, 
         params=params, 
         verify=False)
