@@ -1,7 +1,4 @@
 # coding:utf-8
-from flask import request
-from flask import current_app as app
-from flask import session
 
 def _before_request():
     pass
